@@ -186,7 +186,7 @@ bool Widget::x11Event ( XEvent * event )
 
 void Widget::mousePressEvent ( QMouseEvent * event )
 {
-	QString cmd("/home/user/run_lshal");
+	QString cmd("/opt/batlevel/run_lshal");
 
 	_processPtr->start(cmd);
 	_processPtr->waitForFinished();
